@@ -1,6 +1,7 @@
 #pragma once
-#define R_INTERFACE    1
-#define M_INTERFACE    0
+#define R_INTERFACE    0
+#define M_INTERFACE    1
+#define P_INTERFACE    0
 #define MYMAT_LIBRARY   1
 #define MKL_LIBRARY     0
 #define MATLAB_LIBRARY  0 
@@ -9,8 +10,24 @@
 #ifdef R_RELEASE
 		#undef   R_INTERFACE
 		#undef   M_INTERFACE
+		#undef   P_INTERFACE
 		#define  R_INTERFACE 1
 		#define  M_INTERFACE 0
+        #define  P_INTERFACE 0
+		#undef   MYMAT_LIBRARY
+	    #undef   MKL_LIBRARY
+		#define MYMAT_LIBRARY 1
+	    #define MKL_LIBRARY   0
+	    #define PCGRAND_LIBRARY 1
+        #define MKLRAND_LIBRARY 0
+#endif
+#ifdef P_RELEASE
+		#undef   R_INTERFACE
+		#undef   M_INTERFACE
+		#undef   P_INTERFACE
+		#define  R_INTERFACE 0
+		#define  M_INTERFACE 0
+        #define  P_INTERFACE 1
 		#undef   MYMAT_LIBRARY
 	    #undef   MKL_LIBRARY
 		#define MYMAT_LIBRARY 1
@@ -21,8 +38,10 @@
 #ifdef M_RELEASE
 		#undef   R_INTERFACE
 		#undef   M_INTERFACE
+		#undef   P_INTERFACE
 		#define  R_INTERFACE 0
 		#define  M_INTERFACE 1
+        #define  P_INTERFACE 0
 		#undef   MYMAT_LIBRARY
 	    #undef   MKL_LIBRARY
 		#define MYMAT_LIBRARY 1
@@ -167,8 +186,10 @@
     DISABLE_WARNING(restrict,restrict,NOT_USED)\
     DISABLE_WARNING(switch,switch,NOT_USED) \
     DISABLE_WARNING(uninitialized,uninitialized,NOT_USED)\
-    DISABLE_WARNING(pedantic,pedantic,NOT_USED)
+    DISABLE_WARNING(pedantic,pedantic,NOT_USED) \
+    DISABLE_WARNING(div-by-zero,div-by-zero,NOT_USED)
 	#define  ENABLE_MANY_WARNINGS   \
+    ENABLE_WARNING(div-by-zero,div-by-zero,NOT_USED) \
     ENABLE_WARNING(pedantic,pedantic,NOT_USED)\
     ENABLE_WARNING(uninitialized,uninitialized,NOT_USED)\
     ENABLE_WARNING(switch,switch,NOT_USED)\
@@ -215,8 +236,10 @@
     DISABLE_WARNING(switch,switch,NOT_USED) \
     DISABLE_WARNING(uninitialized,uninitialized,NOT_USED)\
     DISABLE_WARNING(pedantic,pedantic,NOT_USED) \
-    DISABLE_WARNING(typedef-redefinition,typedef-redefinition,NOT_USED) 
+    DISABLE_WARNING(typedef-redefinition,typedef-redefinition,NOT_USED) \
+    DISABLE_WARNING(div-by-zero,div-by-zero,NOT_USED)
 	#define  ENABLE_MANY_WARNINGS  \
+    ENABLE_WARNING(div-by-zero,div-by-zero,NOT_USED) \
     ENABLE_WARNING(typedef-redefinition,typedef-redefinition,NOT_USED)\
     ENABLE_WARNING(pedantic,pedantic,NOT_USED)\
     ENABLE_WARNING(uninitialized,uninitialized,NOT_USED)\
