@@ -4,28 +4,31 @@
 #ifdef MSVC_COMPILER
 	#if R_INTERFACE==1
 		#define DllExport   __declspec( dllexport ) 
+	#elif P_INTERFACE==1
+		#define DllExport   __declspec( dllexport ) 
 	#elif M_INTERFACE==1
 		#define DllExport 
 		#pragma comment(linker,"/export:mexFunction")  
     #endif
-	#define INCLUDE_PTHREAD(_X_) QUOTE_IT(C:/USERS/zehaokg/Documents/Visual Studio 2013/Projects/Matlab_Mex_Test/Pthread_IncludeLib/_X_ )
+	#define INCLUDE_PTHREAD(_X_) QUOTE_IT(C:/USERS/zhaokg/Documents/Visual Studio 2013/Projects/Matlab_Mex_Test/Pthread_IncludeLib/_X_ )
 	#define INCLUDE_MATLAB(_X_)  QUOTE_IT(C:/Program Files/MATLAB/R2019a/extern/include/_X_ )
 	#define INCLUDE_MKL(_X_)     QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/mkl/latest/include/_X_ )
 	#define INCLUDE_IPP(_X_)     QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/ipp/latest/include/_X_ )
 	#define INCLUDE_R(_X_)       QUOTE_IT(C:/Program Files/R/R-3.6.2/include/_X_ )
+    #define LIB_FORTRAN(_X_) QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/compiler/latest/windows/compiler/lib/intel64_win/_X_ )
 	#define LIB_PTHREAD(_X_) QUOTE_IT(C:/USERS/zhaokg/Documents/Visual Studio 2013/Projects/Matlab_Mex_Test/Pthread_IncludeLib/_X_ )
 	#define LIB_MATLAB(_X_)  QUOTE_IT(C:/Program Files/MATLAB/R2019a/extern/lib/win64/microsoft/_X_ )
 	#define LIB_TBB(_X_)     QUOTE_IT(C:/Program Files (x86)/IntelSWTools/compilers_and_libraries/windows/tbb/lib/intel64_win/vc_mt/_X_ )
 	#define LIB_MKL(_X_)     QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/mkl/latest/lib/intel64/_X_ )
 	#define LIB_IPP(_X_)     QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/ipp/latest/lib/intel64/_X_ )
     #define LIB_OpenMP(_X_)  QUOTE_IT(C:/Program Files (x86)/IntelSWTools/compilers_and_libraries/windows/compiler/lib/intel64_win/_X_ )
-	#define LIB_MyLIB(_X_)   QUOTE_IT(C:/Share/Fortran_blas_lib/_X_ )
-#ifdef TARGET_32
-	#define LIB_R(_X_)       QUOTE_IT(C:/Program Files/R/R-4.1.0/implib/i386/_X_ )
-#else
-	#define LIB_R(_X_)       QUOTE_IT(C:/Program Files/R/R-4.1.0/implib/_X_ )
-#endif
-	#define LIB_FORTRAN(_X_) QUOTE_IT(C:/Program Files (x86)/Intel/oneAPI/compiler/latest/windows/compiler/lib/intel64_win/_X_ )
+	#define LIB_MyLIB(_X_)   QUOTE_IT(D:/Share/Fortran_blas_lib/_X_ )
+    #define LIB_Python(_X_)  QUOTE_IT(C:/Anaconda3/libs/_X_ )
+    #define LIB_R(_X_)       QUOTE_IT(C:/Program Files/R/R-4.2.2/implib/_X_ )
+	#ifdef TARGET_32
+        #undef  LIB_R
+		#define LIB_R(_X_)       QUOTE_IT(C:/Program Files/R/R-4.2.2/implib/i386/_X_ )			
+	#endif
 	#if R_INTERFACE==1
 		#pragma comment( lib,LIB_R(R.lib)       )
 		#pragma comment( lib,LIB_R(Rblas.lib)   )
@@ -88,10 +91,22 @@
 	#include <R.h>
 	#include <Rinternals.h>
 	#include <Rdefines.h>
-	#include "Rmath.h"
-	#include "R_ext/GraphicsEngine.h"
-	#include "R_ext/GraphicsDevice.h"	
+	#include <Rmath.h>
+	#include <R_ext/GraphicsEngine.h>
+	#include <R_ext/GraphicsDevice.h>	
 	#if MYMAT_LIBRARY==1
 	#endif
 	#define mwSize size_t
 #endif
+#if P_INTERFACE==1
+	#include "Python.h"     
+	#include "structmember.h"
+	#ifdef  IMPORT_NUMPY
+	   #define PY_ARRAY_UNIQUE_SYMBOL NumpyAPIList
+	   #include "numpy/arrayobject.h"
+	#else
+		#define NO_IMPORT_ARRAY
+		#define PY_ARRAY_UNIQUE_SYMBOL NumpyAPIList
+		#include "numpy/arrayobject.h"
+	#endif
+#endif
