@@ -3,6 +3,8 @@
 #include "abc_000_macro.h"
 #include "abc_mem.h"
 #include "abc_datatype.h"       
+char* word_wrap(char* str,int LINE_LENGTH);
+char* word_wrap_indented(char* str,int LINE_LENGTH,int nspace);
 extern void    ToUpper(char* s);
 extern void    QuickSortD(F32PTR arr,I32PTR  index,I32 low,I32 high);
 extern void    QuickSortA(F32PTR arr,I32PTR  index,I32 low,I32 high);
@@ -11,9 +13,8 @@ extern I32     strcicmp_nfirst(char const* _restrict a,char const* _restrict b,i
 extern I32     strmatch(char const* _restrict full,char const* _restrict part);
 extern F32     DeterminePeriod(F32PTR Y,I32 N);
 extern I32     FindChangepoint(F32PTR prob,F32PTR mem,F32 threshold,I32PTR cpt,F32PTR cptCI,I32 N,I32 minSepDist,I32 maxCptNumber);
-extern void WriteF32ArraryToStrideMEM(F32PTR src,VOID_PTR dst,I64 N,I64 stride,I64 offset,DATA_TYPE dtype);
-extern void CopyStrideMEMToF32Arr(F32PTR dst,VOID_PTR src,int N,int srcStride,int srcOffset,DATA_TYPE srcDataType);
-extern void WriteStrideMEMToArrMEM(VOID_PTR dst,VOID_PTR src,int N,int srcStride,int srcOffset,DATA_TYPE srcDstDataType);
+extern void SetupRoutines_ByCPU(Bool quiet);
+extern void SetupRoutines_UserChoice(int avxOption);
 #define    CopyInsertNewElement(SRC,NSRC,DST,newPos,newValue,T)                                     \
                          memcpy(DST,SRC,(newPos-1)*sizeof(T));        \
 	                     *((T*)DST+newPos-1L)=newValue;                                             \
