@@ -2,7 +2,7 @@
 #include <inttypes.h> 
 #include <float.h>
 #include "abc_000_macro.h"
-#define FLOAT_TYPE 4   
+#define FLOAT_TYPE 4  
 #ifdef FLOAT
 #undef FLOAT
 #endif
@@ -89,18 +89,26 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#if R_INTERFACE==1
-	#ifndef bool
-	#define  bool  unsigned char
+#if R_INTERFACE==1||P_INTERFACE==1
+	#ifndef Bool
+		#define  Bool  unsigned char
 	#endif
-	enum { false=0,true=1 };
+#elif M_INTERFACE==1
+	#ifndef Bool
+		 #include "mex.h"
+		 #define  Bool  bool     
+    #endif
 #endif
+enum { _False_=0,_True_=1 };
 #ifdef CLANG_COMPILER
 	#undef sign   
 	#undef warning 
 #endif
 #if defined (MSVC_COMPILER)
-	static INLINE F32  getNaN() { return (F32)1e38f * (F32)1e38f * (F32)0.f; }
+	static INLINE F32  getNaN(void) { return (F32)1e38f * (F32)1e38f * (F32)0.f; }
 #else
-	static INLINE F32  getNaN() { return (F32) (0.0/0.0); }
+	static INLINE F32  getNaN(void) { return (F32) (0.0/0.0); }
 #endif
+#include <string.h>   
+#define  free0(p)     if(p){ free(p);p=NULL;}
+#define  malloc0(n)   calloc(1L,n)
